@@ -63,6 +63,17 @@ def download_file_to(url, path):
         f.write(r.content)
 
 
+def download_files(records, parallelism):
+    with ThreadPoolExecutor(max_workers=args.parallelism) as t:
+        [
+            _
+            for _ in t.map(
+                lambda r: download_file_to(r["url"], workdir.joinpath(r["name"])),
+                records,
+            )
+        ]
+
+
 def main(args):
     impira = Impira(config=Impira.Config(**vars(args)))
     workdir = pathlib.Path(args.data).joinpath("capture", args.collection + "-" + str(uuid4())[:4])
@@ -77,15 +88,7 @@ def main(args):
     workdir.mkdir(parents=True, exist_ok=True)
 
     if args.download_files:
-        with ThreadPoolExecutor(max_workers=args.parallelism) as t:
-            [
-                _
-                for _ in t.map(
-                    lambda r: download_file_to(r["url"], workdir.joinpath(r["name"])),
-                    records,
-                )
-            ]
-
+        download_files(records, args.parallelism)
         docs = [{"fname": r["name"], "record": r["record"]} for r in records]
     else:
         docs = [{"fname": r["name"], "url": r["url"], "record": r["record"]} for r in records]
